O que é OiRA? | OiRA

Temas

# O que é OiRA?

## É a primeira vez que acede a OiRA?

Leia esta breve introdução ao processo de avaliação de riscos e veja como OiRA pode ajudá-lo a gerir as suas avaliações de riscos.

## O que é a avaliação de riscos?

A avaliação de riscos constitui a base para uma gestão eficiente da saúde e segurança, sendo fundamental para reduzir acidentes relacionados com o trabalho e doenças profissionais. Se for devidamente implementada, pode melhorar a segurança e a saúde no local de trabalho, bem como o desempenho das empresas em geral.

Na Europa, existem meios para garantir a segurança e a saúde dos trabalhadores, incluindo, por exemplo, a avaliação e gestão de riscos no trabalho. As entidades patronais têm a obrigação legal de garantir a segurança e a saúde dos trabalhadores em todos os aspetos relacionados com o trabalho e de proceder a uma avaliação de riscos. Todas as empresas devem, deste modo, realizar uma avaliação de riscos e elaborar um plano de ação. Para realizar uma avaliação eficaz dos riscos no local de trabalho, todas as partes envolvidas devem compreender claramente:

- o contexto e os conceitos jurídicos;
- o processo utilizado para avaliar os riscos;
- o papel a desempenhar pelos principais intervenientes no processo.

Os trabalhadores e/ou os seus representantes têm o direito de ser consultados sobre os procedimentos que envolvem uma avaliação de riscos e a sua participação nessa avaliação.

Para mais informações sobre avaliação de riscos e participação dos trabalhadores e/ou seus representantes no processo de avaliação de riscos, visite o sítio Web do projeto OiRA.

## O que é OiRA?

OiRA é a sigla inglesa para Avaliação de Riscos Interativa em Linha («Online Interactive Risk Assessment»). Trata-se de uma aplicação baseada na Internet que lhe permite realizar uma avaliação de riscos de segurança e saúde para o seu local de trabalho.

## A quem se destina OiRA?

A ferramenta OiRA pode ser utilizada por qualquer pessoa para avaliar riscos de segurança e de saúde que possam existir no seu local de trabalho.

Foi, no entanto, concebida para proporcionar o mais valioso apoio às empresas de menor dimensão. OiRA foi especificamente desenvolvida para apoiar essas empresas na avaliação dos riscos no trabalho e ajudá-las a elaborar uma avaliação de riscos documentada, incluindo um plano de ação adaptado às necessidades das suas infraestruturas.

## O que tenho de fazer?

O processo de avaliação de riscos de OiRA comporta várias etapas:

- Preparação: algumas ferramentas incluem perguntas relacionadas com o perfil de utilizador, para o ajudar a personalizar a ferramenta de acordo com as especificidades da atividade da sua empresa. Ao responder às perguntas de perfil, a ferramenta irá adaptar-se à sua situação específica e apresentará os módulos relevantes aplicáveis.

- Participação: todas as avaliações de riscos devem envolver a participação ativa dos trabalhadores. A ferramenta permite-lhe imprimir o texto completo da avaliação de riscos, ou partes da mesma, de modo a informar os trabalhadores e obter os seus comentários.

- Identificação de riscos: OiRA apresentará uma série de potenciais riscos ou problemas para a saúde e segurança que podem existir no seu local de trabalho. Ao responder às afirmações/perguntas com «sim» ou «não», indica se esses riscos ou problemas estão presentes. Pode também optar por deixar uma pergunta sem resposta e colocá-la em modo de espera para responder mais tarde.

- Avaliação: algumas ferramentas pedem-lhe para priorizar os riscos identificados. Existem diferentes formas de proceder a essa priorização, em função das decisões tomadas pelos nossos parceiros nacionais OiRA/programadores de ferramentas e da sua abordagem específica. Algumas ferramentas também priorizam os riscos automaticamente em segundo plano e permitem-lhe modificar essas prioridades.

- Plano de ação: para cada risco identificado, a ferramenta pede-lhe para estabelecer uma ou mais medidas para eliminar ou reduzir o risco. A maioria das ferramentas irá sugerir-lhe algumas medidas. Poderá também sempre optar por inserir as suas próprias medidas.

- Relatório: é legalmente obrigado a documentar a sua avaliação de riscos. Na secção de relatórios, encontrará uma variedade de relatórios que o ajudarão a acompanhar a sua avaliação de riscos e as ações/medidas que tenha implementado para eliminar ou mitigar os riscos identificados.

## Quanto tempo demora o processo?

É impossível, em geral, indicar quanto tempo demora uma avaliação a ser realizada, uma vez que as ferramentas diferem consoante o setor e o país.

Pode, no entanto, despender o tempo que tiver disponível para uma avaliação e voltar mais tarde, num momento mais conveniente, retomando o processo no mesmo ponto em que foi interrompido.

## Por que razão tenho de me registar?

A primeira coisa que lhe será solicitada quando iniciar a sua primeira avaliação de riscos é criar uma conta OiRA — um processo simples e rápido.

O registo permite-lhe iniciar simplesmente uma sessão em qualquer momento para retomar avaliações anteriormente iniciadas ou iniciar novas avaliações.

Se é um utilizador registado, poderá também obter uma avaliação de riscos impressa, precisa e atualizada em qualquer momento.

## Necessito de alguma preparação?

Não é necessário nenhum tipo de preparação específica para começar a utilizar a ferramenta; deverá, no entanto, dedicar algum tempo para planear quem irá realizar a avaliação de riscos e de que forma serão os trabalhadores envolvidos no processo.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More